@@ -67,7 +67,7 @@ func TestMain(m *testing.M) {
 // externalProcess is an external "misbehaving" process that won't exit
 // cleanly.
 func externalProcess() {
-	wait := make(chan int, 0)
+	wait := make(chan int)
 	fmt.Fprintln(os.Stdout, "started")
 	<-wait
 	os.Exit(2)
