@@ -11,8 +11,7 @@ import (
 )
 
 // Gather statistics from our infiniband cards
-func (_ *Infiniband) Gather(acc telegraf.Accumulator) error {
-
+func (i *Infiniband) Gather(acc telegraf.Accumulator) error {
 	rdmaDevices := rdmamap.GetRdmaDeviceList()
 
 	if len(rdmaDevices) == 0 {
@@ -41,7 +40,6 @@ func (_ *Infiniband) Gather(acc telegraf.Accumulator) error {
 
 // Add the statistics to the accumulator
 func addStats(dev string, port string, stats []rdmamap.RdmaStatEntry, acc telegraf.Accumulator) {
-
 	// Allow users to filter by card and port
 	tags := map[string]string{"device": dev, "port": port}
 	fields := make(map[string]interface{})
